@@ -1,6 +1,4 @@
-print("Hello from the creator of AutoGit, Saran,Abhilash,Abhiraman,Tarun.
-Kindly do report bug if any.
-This message will not be shown again.:)")
+print("Hello from the creator of AutoGit, Saran,Abhilash,Abhiraman,Tarun.Kindly do report bug if any.This message will not be shown again.:)")
 
 import os
 class AutoGitUtils():
